==> am_mod_evt_0_2.tar.gz: am_mod_evt_0_2/components/evt/config/evt.config.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

$event_config['view']['default_list'] =						"all";
// how many days into the future to list?
$event_config['view']['default_days'] =						30;
$event_config['view']['default_feedbacks_overview'] =		3;

$event_config['user']['status']['barred'] = 				1;
$event_config['user']['status']['pending'] = 				2;
$event_config['user']['status']['active'] = 				3;
$event_config['user']['status']['invite'] =					5;


$event_config['event']['status']['live'] =					1;
$event_config['event']['status']['canceled'] =				2;

$event_config['role']['coordinator'] = 						1;
	
$event_config['event_invite_status'] = 						1;
$event_config['resource']['manage_participation'] = 		1;

$event_config['resource']['user']['manage_participants'] = 	2;
$event_config['resource']['user']['allow_invite'] = 		8;

$event_config['default_participation_permission'] = 		0;

$event_config['level']['registered'] =						1;
$event_config['level']['public'] =							2;


$event_config['type']['open'] = 							1; // auto registration
$event_config['type']['approved'] = 						2; // registration approval
$event_config['type']['invitation'] = 						3; // invitation only


if ($_SESSION['user_core_permission'] & $core_config['resource']['user']['mem_visible']) {
	$event_config['type']['membership_type'] = 				4; // membership type access only 
}

$lang['usoutput_participantser_role'][1] =					"coordinator";




// STATISTIC CONFIGURATION ----------------------------------------------
$event_config['statistic']['total_events'] = 				"1";
$event_config['statistic']['total_event_feedback'] = 		"2";

?>

==> am_mod_evt_0_4.tar.gz: am_mod_evt_0_4/components/evt/config/evt.config.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

$event_config['view']['default_list'] =						"all";
// how many days into the future to list?
$event_config['view']['default_days'] =						30;
$event_config['view']['default_feedbacks_overview'] =		3;
$event_config['view']['default_event_list'] =				"latest"; // "today" // "my_events" // "my_attendance"

$event_config['event']['status']['live'] =					1;
$event_config['event']['status']['canceled'] =				2;

$event_config['role']['coordinator'] = 						1;
	
$event_config['event_invite_status'] = 						1;
$event_config['resource']['manage_participation'] = 		1;

$event_config['resource']['user']['manage_participants'] = 	2;
$event_config['resource']['user']['allow_invite'] = 		8;

$event_config['default_participation_permission'] = 		0;

$event_config['level']['registered'] =						1;
$event_config['level']['public'] =							2;


$event_config['type']['open'] = 							1; // auto registration
$event_config['type']['approved'] = 						2; // registration approval
$event_config['type']['invitation'] = 						3; // invitation only
$event_config['type']['membership_type'] = 					4; // membership type access only


$lang['usoutput_participantser_role'][1] =					"coordinator";




// STATISTIC CONFIGURATION ----------------------------------------------
$event_config['statistic']['total_events'] = 				"1";
$event_config['statistic']['total_event_feedback'] = 		"2";

?>
